@@ -5,6 +5,8 @@ from tamarin.command import Command
 from sentry_sdk import capture_exception
 import uuid
 import datetime
+from tamarin.logs.models import Report
+import traceback
 
 
 class ElasticSearchCommand(Command):
@@ -67,7 +69,15 @@ class ElasticSearchCommand(Command):
                 return {'elastic_id': 'not allowed'}
         except Exception as e:
             capture_exception(e)
-            return {'elastic_id': 'exception occured'}
+            report = Report.objects.create(
+                index='elastic-exception',
+                status=500,
+                text=traceback.format_exc()
+            )
+            return {
+                'elastic_id': 'exception occured',
+                'report': report.id,
+            }
 
     def clean_data_type(self, data):
         if data is None:
