@@ -13,8 +13,9 @@ class LogAdmin(admin.ModelAdmin):
 @admin.register(Report)
 class ReportAdmin(admin.ModelAdmin):
     using = 'log'
-    list_display = ['index', 'status_code', 'created_at']
-    list_filter = ['created_at', 'status_code', 'index']
+
+    list_display = ['index', 'status', 'created_at']
+    list_filter = ['created_at', 'status', 'index']
     search_fields = ['index']
 
     def get_queryset(self, request):
